import csv
import os
import chardet


def get_csv_encoding(file_path):
    # Open the file in binary mode and read a chunk of data
    with open(file_path, 'rb') as file:
        raw_data = file.read(8192)

    # Detect the encoding of the data
    result = chardet.detect(raw_data)
    encoding = result['encoding']

    return encoding


def divide_csv(input_file, output_dir, rows_per_file):
    # Create the output directory if it doesn't exist
    if not os.path.exists(output_dir):
        os.makedirs(output_dir)

    # Determine the encoding of the input CSV file
    encoding = get_csv_encoding(input_file)

    # Open the input CSV file with the detected encoding
    with open(input_file, 'r', encoding=encoding) as file:
        reader = csv.reader(file)
        header = next(reader)  # Read the header row

        file_number = 1
        row_count = 0

        # Open the first output CSV file
        output_file = os.path.join(output_dir, f'output_{file_number}.csv')
        with open(output_file, 'w', newline='', encoding=encoding) as out_file:
            writer = csv.writer(out_file)

            # Write the header row to the output file
            writer.writerow(header)

            # Process the remaining rows
            for row in reader:
                writer.writerow(row)
                row_count += 1

                # If the desired number of rows per file is reached, close the current file and open a new one
                if row_count == rows_per_file:
                    row_count = 0
                    file_number += 1
                    output_file = os.path.join(output_dir, f'output_{file_number}.csv')
                    out_file = open(output_file, 'w', newline='', encoding=encoding)
                    writer = csv.writer(out_file)
                    writer.writerow(header)

            # Close the last output file
            out_file.close()

# Usage example
input_file = '/Users/filip/Desktop/Shumee/Python/csv_splitter/input.csv'  # Path to the input CSV file
output_directory = '/Users/filip/Desktop/Shumee/Python/csv_splitter/output'  # Directory where the output CSV files will be stored
rows_per_output_file = 400  # Number of rows per output CSV file

divide_csv(input_file, output_directory, rows_per_output_file)
